@@ -48,10 +48,10 @@ z<-des$x1
 w<-des$y
                          }
 
- 
+base = high = NULL 
 #Depends on the following libraries
-library(lattice)
-library(grid)
+#library(lattice)
+#library(grid)
 ######################
 ## Creation of Grid ##
 ######################
